==> rocon-1.2.0.tgz: package/esm/builder/StateRouteBuilder/index.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _classPrivateFieldGet from "@babel/runtime/helpers/esm/classPrivateFieldGet";
import _classPrivateFieldSet from "@babel/runtime/helpers/esm/classPrivateFieldSet";
import { BuilderLink } from "../../core/BuilderLink";
import { isUndefinedOr } from "../../validator";
import { StateLocationComposer } from "../composers/StateLocationComposer";
import { MatchingRouteRecord } from "../RouteRecord/MatchingRouteRecord";
import { SingleRouteAbstractBuilder } from "../SingleRouteAbstractBuilder";

var _link = new WeakMap();

var _validator = new WeakMap();

var _route = new WeakMap();

export class StateRouteBuilder extends SingleRouteAbstractBuilder {
  static init(matchKey, validator, options = {}) {
    var _options$stateKey;

    const stateKey = (_options$stateKey = options.stateKey) !== null && _options$stateKey !== void 0 ? _options$stateKey : matchKey;
    const optional = options.optional || false;
    const usedValidator = optional ? isUndefinedOr(validator) : validator;
    const link = new BuilderLink({
      composer: new StateLocationComposer(stateKey, usedValidator, optional)
    });
    const result = new StateRouteBuilder(link, matchKey, usedValidator);
    return result;
  }

  constructor(link, matchKey, validator) {
    super();

    _defineProperty(this, "matchKey", void 0);

    _link.set(this, {
      writable: true,
      value: void 0
    });

    _validator.set(this, {
      writable: true,
      value: void 0
    });

    _route.set(this, {
      writable: true,
      value: void 0
    });

    _classPrivateFieldSet(this, _link, link);

    this.matchKey = matchKey;

    _classPrivateFieldSet(this, _validator, validator);

    _classPrivateFieldSet(this, _route, new MatchingRouteRecord(this, matchKey, validator, undefined));

    link.register(this, value => {
      const route = _classPrivateFieldGet(this, _route);

      return {
        type: "matching",
        value: route,
        link: route.getAttachedBuilderLink(),
        matchKey: matchKey,
        matchValue: value
      };
    });
  }
  /**
   * Define action for this route and return a new instance of StateRouteBuilder.
   */


  action(action) {
    const validator = _classPrivateFieldGet(this, _validator);

    const result = new StateRouteBuilder(_classPrivateFieldGet(this, _link).inherit(), this.matchKey, validator);

    _classPrivateFieldSet(result, _route, new MatchingRouteRecord(result, this.matchKey, validator, action));

    return result;
  }

  getRoute() {
    return _classPrivateFieldGet(this, _route);
  }

  getBuilderLink() {
    return _classPrivateFieldGet(this, _link);
  }

}

==> rocon-1.2.6.tgz: package/esm/builder/StateRouteBuilder/index.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _classPrivateFieldGet from "@babel/runtime/helpers/esm/classPrivateFieldGet";
import _classPrivateFieldSet from "@babel/runtime/helpers/esm/classPrivateFieldSet";

function _classPrivateFieldInitSpec(obj, privateMap, value) { _checkPrivateRedeclaration(obj, privateMap); privateMap.set(obj, value); }

function _checkPrivateRedeclaration(obj, privateCollection) { if (privateCollection.has(obj)) { throw new TypeError("Cannot initialize the same private elements twice on an object"); } }

import { BuilderLink } from "../../core/BuilderLink";
import { isUndefinedOr } from "../../validator";
import { StateLocationComposer } from "../composers/StateLocationComposer";
import { MatchingRouteRecord } from "../RouteRecord/MatchingRouteRecord";
import { SingleRouteAbstractBuilder } from "../SingleRouteAbstractBuilder";

var _link = /*#__PURE__*/new WeakMap();

var _validator = /*#__PURE__*/new WeakMap();

var _route = /*#__PURE__*/new WeakMap();

export class StateRouteBuilder extends SingleRouteAbstractBuilder {
  static init(matchKey, validator, options = {}) {
    var _options$stateKey;

    const stateKey = (_options$stateKey = options.stateKey) !== null && _options$stateKey !== void 0 ? _options$stateKey : matchKey;
    const optional = options.optional || false;
    const usedValidator = optional ? isUndefinedOr(validator) : validator;
    const link = new BuilderLink({
      composer: new StateLocationComposer(stateKey, usedValidator, optional)
    });
    const result = new StateRouteBuilder(link, matchKey, usedValidator);
    return result;
  }

  constructor(link, matchKey, validator) {
    super();

    _defineProperty(this, "matchKey", void 0);

    _classPrivateFieldInitSpec(this, _link, {
      writable: true,
      value: void 0
    });

    _classPrivateFieldInitSpec(this, _validator, {
      writable: true,
      value: void 0
    });

    _classPrivateFieldInitSpec(this, _route, {
      writable: true,
      value: void 0
    });

    _classPrivateFieldSet(this, _link, link);

    this.matchKey = matchKey;

    _classPrivateFieldSet(this, _validator, validator);

    _classPrivateFieldSet(this, _route, new MatchingRouteRecord(this, matchKey, validator, undefined));

    link.register(this, value => {
      const route = _classPrivateFieldGet(this, _route);

      return {
        type: "matching",
        value: route,
        link: route.getAttachedBuilderLink(),
        matchKey: matchKey,
        matchValue: value
      };
    });
  }
  /**
   * Define action for this route and return a new instance of StateRouteBuilder.
   */


  action(action) {
    const validator = _classPrivateFieldGet(this, _validator);

    const result = new StateRouteBuilder(_classPrivateFieldGet(this, _link).inherit(), this.matchKey, validator);

    _classPrivateFieldSet(result, _route, new MatchingRouteRecord(result, this.matchKey, validator, action));

    return result;
  }

  getRoute() {
    return _classPrivateFieldGet(this, _route);
  }

  getBuilderLink() {
    return _classPrivateFieldGet(this, _link);
  }

}
